@@ -1,8 +1,14 @@
-"""hub Fluent API Helper.
+"""hub Fluent API Helper."""
+
+##
+# @file hub.py
+#
+# @brief hub Fluent API Helper.
+#
+# @section description Description
+# This module contains helper methods for calling hub.* Notecard API commands.
+# This module is optional and not required for use with the Notecard.
 
-This module contains helper methods for calling hub.*
-Notecard API commands.
-"""
 import notecard
 from .validators import validate_card_object
 
@@ -14,6 +20,7 @@ def set(card, product, sn=None, mode=None, minutes=None,
     """Configure Notehub behavior on the Notecard.
 
     Args:
+        card (Notecard): The current Notecard object.
         product (string): The ProductUID of the project.
         sn (string): The Serial Number of the device.
         mode (string): The sync mode to use.
@@ -59,6 +66,9 @@ def set(card, product, sn=None, mode=None, minutes=None,
 def sync(card):
     """Initiate a sync of the Notecard to Notehub.
 
+    Args:
+        card (Notecard): The current Notecard object.
+
     Returns:
         string: The result of the Notecard request.
     """
@@ -71,6 +81,7 @@ def syncStatus(card, sync=None):
     """Retrive the status of a sync request.
 
     Args:
+        card (Notecard): The current Notecard object.
         sync (bool): True if sync should be auto-initiated pending
             outbound data.
 
@@ -88,6 +99,9 @@ def syncStatus(card, sync=None):
 def status(card):
     """Retrieve the status of the Notecard's connection.
 
+    Args:
+        card (Notecard): The current Notecard object.
+
     Returns:
         string: The result of the Notecard request.
     """
@@ -100,6 +114,7 @@ def log(card, text, alert=False, sync=False):
     """Send a log request to the Notecard.
 
     Args:
+        card (Notecard): The current Notecard object.
         text (string): The ProductUID of the project.
         alert (bool): True if the message is urgent.
         sync (bool): Whether to sync right away.
@@ -118,6 +133,9 @@ def log(card, text, alert=False, sync=False):
 def get(card):
     """Retrive the current Notehub configuration parameters.
 
+    Args:
+        card (Notecard): The current Notecard object.
+
     Returns:
         string: The result of the Notecard request.
     """
